New Hampshire Judicial Branch - Supreme Court
Description: The website for the New Hampshire Judicial Branch of Government
Keywords: courts, supreme court, superior court, district court, probate court, family division, judiciary, justices, judges, law, NH, New Hampshire

Accessibility Options | FAQ | Site Map | Contact Us | Text + Text -

### Supreme Court

- Welcome
- About the Court
- Court Location
- Meet the Justices
- Court Rules
- Cases Accepted
- Oral Argument Calendar
- Slip Opinions
- Orders
- 3JX Orders
- Amicus Announcements
- Request to Review File
- eBriefs
- List Service
- Mediation
- Advisory Committee on Rules

###

Quick Links
Forms
Filing Fees
FAQ
Contact

###

Supreme Court - 2014 Opinions

NOTICE: These opinions are subject to motions for rehearing under Rule 22 as well as formal revision before publication in the New Hampshire Reports. Readers are requested to notify the Reporter, Supreme Court of New Hampshire, One Charles Doe Drive, Concord, New Hampshire 03301, of any editorial errors in order that corrections may be made before the opinion goes to press. Errors may be reported by E-mail at the following address: reporter@courts.state.nh.us.

Opinions are in Adobe Acrobat format (to download a free copy of Adobe Acrobat Reader, go to http://www.adobe.com).

July 2, 2014

- 2013-0354, Thomas Ettinger & a. v. Pomeroy Limited Partnership & a.
- 2013-0403, 2013-0445, and 2013-0593, In re Guardianship of Madelyn B.

June 24, 2014

- 2012-0696, In the Matter of Marcus J. Hampers and Kristin C. Hampers

June 20, 2014

- 2012-0581, State of New Hampshire v. William Gaudet
- 2012-0817, State of New Hampshire v. Stephen Stangle
- 2012-0926, Kathleen Boulter v. Eli and Bessie Cohen Foundation d/b/a Cohen Camps

June 18, 2014

- 2012-0724, Gary Dube & a. v. New Hampshire Department of Health and Human Services & a.
- 2013-0206, Kenneth England v. Maria Brianas
- 2013-0258, Diana Camire v. The Gunstock Area Commission
- 2013-0504, Appeal of Coos County Commissioners o/b/o the Unincorporated Places of Dixville, NH and Millsfield, NH

June 13, 2014

- 2013-0035, David P. Eby & a. v. State of New Hampshire
- 2013-0058, State of New Hampshire v. Jamie Locke
- 2013-0359, In the Matter of the State of New Hampshire and Cory R. Lounder

May 30, 2014

- 2013-0401, In the Matter of John G. Lyon and Kimberly Anne White Lyon

May 22, 2014

- 2012-0561, State of New Hampshire v. Barion Perry
- 2012-0828, Appeal of New Hampshire Right to Life

May 16, 2014

- 2012-0443, Leigh Mae Friedline & a. v. Eugene Roe
- 2012-0674, State of New Hampshire v. Robert Letoile, Jr.
- 2012-0716, State of New Hampshire v. Bryan Maga
- 2012-0827, State of New Hampshire v. Theadore Mitchell

May 8, 2014

- 2013-075, The State of New Hampshire v. Thomas Jur
- 2013-230, Tamara Dukette v. Daniel Brazas
- 2013-313, Appeal of Niadni, Inc. d/b/a Indian Head Resort Motel

May 7, 2014

- 2012-624, David Montenegro v. New Hampshire Division of Motor Vehicles
- 2012-798, Appeal of Town of North Hampton

April 18, 2014

- 2012-873, In re G.G.
- 2013-253, Appeal of Town of Brookline
- 2013-266, State of New Hampshire v. Gregory Collins

April 15, 2014

- 2012-475, State of New Hampshire v. Hillman Blesdell-Moore

April 11, 2014

- 2013-184, Dennis G. Huckins v. Mark McSweeney & a.

April 4, 2014

- 2012-045, State of New Hampshire v. David Pyles
- 2012-719, State of New Hampshire v. Arthur Mottola

March 20, 2014

- 2012-268, State of New Hampshire v. Dennis Sulloway

March 14, 2014

- 2012-902, Kenneth Lahm v. Michael Farrington & a.

March 7, 2014

- 2008-945, State of New Hampshire v. Michael Addison (Motion to Disqualify Attorney General’s Office)
- 2012-078, State of New Hampshire v. Tariq Zubhuza
- 2012-372, Lucien Vincent v. Davina MacLean
- 2013-043, William L. O'Brien v. New Hampshire Democratic Party & a.

February 21, 2014

- 2012-0560, State of New Hampshire v. Osahenrumwen Ojo
- 2012-0850, In re Estate of Lucien Couture

February 13, 2014

- 2012-441, State of New Hampshire v. Adam Wells
- 2012-623, In the Matter of the Liquidation of The Home Insurance Company (Modified March 5, 2014: see court order)

February 11, 2014

- 2012-572, State of New Hampshire v. Chad Belleville
- 2012-644, State of New Hampshire v. Adam Mueller

February 7, 2014

- 2012-920, In re Trevor G.

January 28, 2014

- 2012-313, State of New Hampshire v. John A. Smith
- 2012-323, State of New Hampshire v. William Ramsey

January 17, 2014

- 2011-500, State of New Hampshire v. Joshua Sprague

January 14, 2014

- 2012-481, State of New Hampshire v. Richard Gness
- 2012-632, State of New Hampshire v. Kurt Carpentino
- 2012-802, State of New Hampshire v. Barion Perry

January 10, 2014

- 2012-729, Appeal of the Local Government Center, Inc. & a .

Accessibility Options | FAQ | Site Map | Contact Us | N.H. Legislative Branch | N.H. Executive Branch | NH.Gov | Revised Statutes Online